'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _index = require('./index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// List of API methods that should be prevented in read-only mode
var dangerousMethods = ['mkdir', 'rename', 'rmdir', 'unlink', 'writeFile'];

/**
 * Create a read-only fs-like API for Dropbox
 * 
 * @param {{
 *  apiKey: String,
 *  client: Dropbox,
 * }} Configuration object
 * @returns {Object}
 */

exports.default = function (_ref) {
    var client = _ref.client,
        apiKey = _ref.apiKey;


    var api = (0, _index2.default)({ client: client, apiKey: apiKey });

    var returnError = function returnError(method) {
        return function () {
            var _ref2;

            var cb = (_ref2 = arguments.length - 1, arguments.length <= _ref2 ? undefined : arguments[_ref2]);
            cb(method + ' is not supported in read-only mode');
        };
    };

    // Replace dangerous methods with safe ones
    dangerousMethods.forEach(function (method) {
        api[method] = returnError(method);
    });

    return api;
};

module.exports = exports['default'];